#include <unistd.h>
#include <stdio.h>

int main(int argc, char **argv)
{
	long av_pages, tot_pages, pagesize;
	long av_human, tot_human;
	int hshift = 0, shifter = 0;
	float av_pct;
	const char suffix[] = "KMGT";

	tot_pages = sysconf(_SC_PHYS_PAGES);
	av_pages = sysconf(_SC_AVPHYS_PAGES);
	pagesize = sysconf(_SC_PAGESIZE);

	/* get the value to shift by in order to transliterate
	 * available resources as kilobyte blocks */
	while (pagesize >> shifter > 1024)
		shifter++;

	/* get human-readable numbers in KiB */
	av_human = av_pages << shifter;
	tot_human = tot_pages << shifter;

	/* Find some suitable number to left-shift with to
	 * get a decent human representation */
	while (av_human >> (hshift * 10) >= 1024)
		hshift++;
	av_human >>= hshift * 10;
	tot_human >>= hshift * 10;

	/* get percent values */
	av_pct = (float)av_pages / (float)tot_pages;
	printf("%.2f%% memory free (%ld pages of %ld bytes each)\n",
	       av_pct, av_pages, pagesize);
	printf("av_human: %ld %ciB; tot_human: %ld %ciB\n",
		   av_human, suffix[hshift], tot_human, suffix[hshift]);

	return 0;
}
